# 自然语言


# 1 分类

# 2 抽取


```
import nlp_rules
from nlp_rules import RegularRules
from nlp_rules import RegularRulesNer

mrr = RegularRules()
mrr.predict("xxx")
mnr = RegularRulesNer()
mnr.predict("xxx")

```

